@@ -55,9 +55,9 @@ namespace ROPTLIB{
 
 		Rprintf("RNEWTON METHOD PARAMETERS:\n");
 		status = (Min_Inner_Iter >= 0 && Min_Inner_Iter <= Max_Inner_Iter) ? YES : NO;
-		Rprintf("Min_Inner_Iter:%15d[%s],\t", Min_Inner_Iter, status);
+		Rprintf("Min_Inner_Iter:%15ld[%s],\t", Min_Inner_Iter, status);
 		status = (Max_Inner_Iter >= 0 && Max_Inner_Iter >= Min_Inner_Iter) ? YES : NO;
-		Rprintf("Max_Inner_Iter:%15d[%s],\t", Max_Inner_Iter, status);
+		Rprintf("Max_Inner_Iter:%15ld[%s],\t", Max_Inner_Iter, status);
 		status = (theta >= 1) ? YES : NO;
 		Rprintf("theta         :%15g[%s],\t", theta, status);
 		status = (kappa > 0 && kappa < 1) ? YES : NO;
@@ -87,7 +87,7 @@ namespace ROPTLIB{
 
 	void RNewton::PrintInfo(void)
 	{
-		Rprintf("\n\tnH:%d,tCGstatus:%s,innerIter:%d,", nH, tCGLSstatusSetnames[tCGLSstatus].c_str(), innerIter);
+		Rprintf("\n\tnH:%ld,tCGstatus:%s,innerIter:%ld,", nH, tCGLSstatusSetnames[tCGLSstatus].c_str(), innerIter);
 		Rprintf("\n");
 	};
 
